@@ -45,7 +45,7 @@ class AbstractBrowser:
         self.scan_mode = "all"
         self.history = [os.getcwd()]
         self.modes = ['-SCAN_MODE_FILES-','-SCAN_MODE_FOLDERS-','-SCAN_MODE_ALL-']
-        self.key_list = ['-BROWSER_LIST-','-CLEAR_LIST-','-ADD_TO_LIST-',"-FILES_BROWSER-","-DIR-","-DIRECTORY_BROWSER-","-FILES_LIST-","-SCAN_MODE_ALL-","-SELECT_HIGHLIGHTED-","-SCAN-", "-SELECT_HIGHLIGHTED-", "-MODE-", "-BROWSE_BACKWARDS-", "-BROWSE_FORWARDS-"]+self.modes
+        self.key_list = ['-BROWSER_LIST-','-CLEAR_LIST-','-MOVE_UP_LIST-','-MOVE_DOWN_LIST-','-ADD_TO_LIST-',"-FILES_BROWSER-","-DIR-","-DIRECTORY_BROWSER-","-FILES_LIST-","-SCAN_MODE_ALL-","-SELECT_HIGHLIGHTED-","-SCAN-", "-SELECT_HIGHLIGHTED-", "-MODE-", "-BROWSE_BACKWARDS-", "-BROWSE_FORWARDS-"]+self.modes
 
     def handle_event(self,event,values,window):
           
@@ -146,7 +146,7 @@ class AbstractBrowser:
             self.window.Element(self.event_key_js['-MODE-']).update(text=f"{capitalize(self.scan_mode)} Scan Mode")
             self.scan_it(self.return_directory())
         if self.event_key_js['found'] in ['-MOVE_UP_LIST-','-MOVE_DOWN_LIST-']:
-            
+            self.list_it()
         if self.event_key_js['found'] == '-ADD_TO_LIST-':
             file_list = self.values[self.event_key_js['-BROWSER_LIST-']]
             files_list = self.values[self.event_key_js['-FILES_LIST-']] or []
@@ -183,7 +183,7 @@ class AbstractBrowser:
             except:
                 print(f'could not scan directory {directory}')
         return self.event,self.values
-    def list_it():
+    def list_it(self):
         def get_list_num(list_obj, var):
             if list_obj:
                 if var == list_obj[-1]:
@@ -221,8 +221,7 @@ class AbstractBrowser:
                         list_values, list_value, position, direction)
                 if direction == 'down' and position < len(list_values)-1:
                     list_values.remove(list_value)
-                    list_values = add_position(
-                        list_values, list_value, position, direction)
+                    list_values = add_position(list_values, list_value, position, direction)
                 self.window[self.event_key_js['-FILES_LIST-']].update(values=list_values)
                 self.window[self.event_key_js['-FILES_LIST-']].update(
                     set_to_index=[get_list_num(list_values, list_value)])
